@@ -17,8 +17,15 @@ import bento.tool_runner
 from bento.config import get_valid_tools, update_tool_run
 from bento.context import Context
 from bento.decorators import with_metrics
-from bento.error import NodeError
+from bento.error import (
+    BentoException,
+    NoConfigurationException,
+    NodeError,
+    NoIgnoreFileException,
+    ToolRunException,
+)
 from bento.paths import list_paths
+from bento.result import Baseline
 from bento.target_file_manager import TargetFileManager
 from bento.tool import Tool
 from bento.util import echo_error, echo_next_step, echo_success, echo_warning
@@ -91,8 +98,11 @@ def check(
 
     # Fail out if not configured
     if not context.config_path.exists():
-        echo_error("No Bento configuration found. Please run `bento init`.")
-        sys.exit(3)
+        raise NoConfigurationException()
+
+    # Fail out if no .bentoignore
+    if not context.ignore_file_path.exists():
+        raise NoIgnoreFileException(context)
 
     # Default to no path filter
     if len(paths) < 1:
@@ -123,17 +133,21 @@ def check(
     if tool:
         tools = [context.configured_tools[tool]]
 
+    baseline: Baseline = {}
+    if context.baseline_file_path.exists():
+        with context.baseline_file_path.open() as json_file:
+            baseline = bento.result.json_to_violation_hashes(json_file)
+
     target_file_manager = TargetFileManager(
         context.base_path, path_list, not all_, context.ignore_file_path
     )
-    target_paths = target_file_manager.get_target_files()
+
     all_results, elapsed = bento.orchestrator.orchestrate(
-        context, target_paths, not all_, tools
+        baseline, target_file_manager, not all_, tools
     )
 
     fmts = context.formatters
     findings_to_log: List[Any] = []
-    is_error = False
     n_all = 0
     n_all_filtered = 0
     filtered_findings: Dict[str, List[Violation]] = {}
@@ -141,26 +155,28 @@ def check(
         if isinstance(findings, Exception):
             logging.error(findings)
             echo_error(f"Error while running {tool_id}: {findings}")
-            if isinstance(findings, subprocess.CalledProcessError):
-                click.secho(findings.stderr, err=True)
-                click.secho(findings.stdout, err=True)
-            if isinstance(findings, NodeError):
-                echo_warning(
-                    f"Node.js not found or version is not compatible with ESLint v6."
+            if isinstance(findings, BentoException):
+                click.secho(findings.msg, err=True)
+            else:
+                if isinstance(findings, subprocess.CalledProcessError):
+                    click.secho(findings.stderr, err=True)
+                    click.secho(findings.stdout, err=True)
+                if isinstance(findings, NodeError):
+                    echo_warning(
+                        f"Node.js not found or version is not compatible with ESLint v6."
+                    )
+                click.secho(
+                    f"""-------------------------------------------------------------------------------------------------
+    This may be due to a corrupted tool installation. You might be able to fix this issue by running:
+
+    bento init --clean
+
+    You can also view full details of this error in `{bento.constants.DEFAULT_LOG_PATH}`.
+    -------------------------------------------------------------------------------------------------
+    """,
+                    err=True,
                 )
-
-            click.secho(
-                f"""-------------------------------------------------------------------------------------------------
-This may be due to a corrupted tool installation. You might be able to fix this issue by running:
-
-  bento init --clean
-
-You can also view full details of this error in `{bento.constants.DEFAULT_LOG_PATH}`.
--------------------------------------------------------------------------------------------------
-""",
-                err=True,
-            )
-            is_error = True
+            context.error_on_exit(ToolRunException())
         elif isinstance(findings, list) and findings:
             findings_to_log += bento.metrics.violations_to_metrics(
                 tool_id,
@@ -207,7 +223,7 @@ You can also view full details of this error in `{bento.constants.DEFAULT_LOG_PA
 
     if not all_ and not context.autorun_is_blocking:
         return
-    elif is_error:
-        sys.exit(3)
+    elif context.on_exit_exception:
+        raise context.on_exit_exception
     elif n_all_filtered > 0:
         sys.exit(2)
