@@ -1,18 +1,18 @@
 import json
 import logging
 import os
+import re
 import subprocess
 import sys
 import venv
 from abc import abstractmethod
 from pathlib import Path
 from time import time
-from typing import Dict, Generic, List
+from typing import Dict, Generic, List, Optional, Pattern
 
 from semantic_version import SimpleSpec, Version
 
 import bento.constants as constants
-from bento.base_context import BaseContext
 from bento.tool import R, Tool
 
 
@@ -22,10 +22,19 @@ class PythonTool(Generic[R], Tool[R]):
     # we hard code to python3
     PIP_CMD = ["python3", "-m", "pip"]
     PACKAGES: Dict[str, SimpleSpec] = {}
+    PYTHON_FILE_PATTERN = re.compile(r".*\.py$")
+    SHEBANG_PATTERN = re.compile(r"^#!.*python")
 
-    @classmethod
-    def matches_project(cls, context: BaseContext) -> bool:
-        return cls.project_has_extensions(context, "*.py")
+    @property
+    def shebang_pattern(self) -> Optional[Pattern]:
+        return self.SHEBANG_PATTERN
+
+    def matches_project(self) -> bool:
+        return self.project_has_file_paths()
+
+    @property
+    def file_name_filter(self) -> Pattern:
+        return self.PYTHON_FILE_PATTERN
 
     @classmethod
     @abstractmethod
@@ -67,7 +76,7 @@ class PythonTool(Generic[R], Tool[R]):
         before = time()
         env = dict(os.environ)
         env["VIRTUAL_ENV"] = str(self.venv_dir())
-        env["PATH"] = f"{self.venv_dir()}/bin:" + env["PATH"]
+        env["PATH"] = f"{self.venv_dir()}:{self.venv_dir()}/bin:" + env["PATH"]
         if "PYTHONHOME" in env:
             del env["PYTHONHOME"]
         v = subprocess.Popen(
