@@ -19,7 +19,7 @@ COMMENT_START_REGEX = re.compile(r"(?P<ignore_pattern>.*?)(?:\s+|^)#.*")
 
 
 @attr.s
-class Entry(object):
+class Entry:
     path = attr.ib(type=Path)
     survives = attr.ib(type=bool)
 
@@ -59,11 +59,26 @@ class FileIgnore(Mapping[Path, Entry]):
                 return False
             if fnmatch.fnmatch(str(path), p):
                 return False
+
             # Check any subpath of path satisfies a pattern
+            # i.e. a/b/c/d is ignored with rule a/b
             # This is a hack. TargetFileManager should be pruning while searching
             # instead of post filtering to avoid this
-            if p.endswith("/") and fnmatch.fnmatch(str(path), p + "*"):
+            # Note: Use relative to base to avoid ignore rules firing on parent directories
+            # i.e. /private/var/.../instabot should not be ignored with var/ rule
+            # in instabot dir as base_path
+            # Note: Append "/" to path before running fnmatch so **/pattern matches with pattern/stuff
+            if p.endswith("/") and fnmatch.fnmatch(
+                "/" + str(path.relative_to(self.base_path)), p + "*"
+            ):
                 return False
+            if (
+                p.endswith("/")
+                and p.startswith(str(self.base_path))
+                and fnmatch.fnmatch(str(path), p + "*")
+            ):
+                return False
+
         return True
 
     def _walk(self, this_path: str, root_path: str) -> Iterator[Entry]:
@@ -134,7 +149,7 @@ class FileIgnore(Mapping[Path, Entry]):
 
 
 @attr.s(auto_attribs=True)
-class Parser(object):
+class Parser:
     r"""
     A parser for bentoignore syntax.
 
@@ -223,7 +238,7 @@ class Parser(object):
 
 
 @attr.s(auto_attribs=True)
-class Processor(object):
+class Processor:
     """
     A post-processor for parsed bentoignore files.
 
